/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.attributes;

import java.io.Serializable;

/**
 * Class IntegerAttributeValue represents an integer attribute value.
 *
 * @author Marko Reiprecht
 *         Created on 26.03.2007
 * @version $Revision: 2281 $
 */
public class IntegerAttributeValue extends AttributeValueAdapter implements Serializable {

    // ------------------------------ FIELDS ------------------------------

    /**
     * Field serialVersionUID.
     */
    private static final long serialVersionUID = -3507045408179616564L;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor IntegerAttributeValue creates a new IntegerAttributeValue instance.
     *
     * @param wrappedObject of type int
     */
    public IntegerAttributeValue(final int wrappedObject) {
        this(new Integer(wrappedObject));
    }

    /**
     * Constructor IntegerAttributeValue creates a new IntegerAttributeValue instance.
     *
     * @param wrappedObject of type Integer
     * @throws NullPointerException when wrappedObject is null
     */
    public IntegerAttributeValue(final Integer wrappedObject) throws NullPointerException {
        super(wrappedObject);
    }

    // -------------------------- OTHER METHODS --------------------------

    /**
     * Method getIntValue returns the intValue of this IntegerAttributeValue object.
     *
     * @return the intValue (type int) of this IntegerAttributeValue object.
     */
    public int getIntValue() {
        return getValue().intValue();
    }

    /**
     * Method getValue returns the value of this IntegerAttributeValue object.
     *
     * @return the value (type Integer) of this IntegerAttributeValue object.
     */
    public Integer getValue() {
        return (Integer) m_wrappedObject;
    }
}
