/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 18.07.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.crypto;

import java.security.Key;
import java.security.PublicKey;
import java.security.cert.Certificate;

/**
 * Class KeyPair encapsulates the concept of a private-public-keypair.
 *
 * @author Marko Reiprecht
 *         Created on 18.07.2008
 * @version $Revision: $
 */
public interface KeyPair {

    // -------------------------- OTHER METHODS --------------------------

    /**
     * Method gets the alias for the keypair.
     * Can be the empty string if unused.
     *
     * @return String.
     */
    String getAlias();

    /**
     * Method gets the certificate if one exists.
     *
     * @return X509Certificate or null.
     */
    Certificate getCertificate();

    /**
     * Method gets the CertificateChain.
     *
     * @return Certificate[].
     */
    Certificate[] getCertificateChain();

    /**
     * Method gets the privateKey.
     * This can be a {@link java.security.PrivateKey} or a {@link javax.crypto.SecretKey}
     *
     * @return Key.
     */
    Key getPrivateKey();

    /**
     * Method gets the publicKey.
     * <p/>
     * if a X509Certificate exists than this method shall return getCertificate().getPublicKey();
     *
     * @return PublicKey.
     */
    PublicKey getPublicKey();

    /**
     * Returns if the pair bean contains a certificate chain.
     *
     * @return boolean.
     */
    boolean isCertificateChainSet();

    /**
     * Returns if the pair bean contains a certificate.
     *
     * @return boolean.
     */
    boolean isCertificateSet();

    /**
     * Returns if the pair bean contains a private key.
     *
     * @return boolean.
     */
    boolean isPrivateKeySet();

    /**
     * Returns if the pair bean contains a public key.
     *
     * @return boolean.
     */
    boolean isPublicKeySet();
}
