/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.util;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpressionException;
import javax.xml.xpath.XPathFactory;
import java.io.IOException;
import java.io.InputStream;

/**
 * Helper class for XPath queries.
 * @deprecated please use the {@link org.n52.security.common.xml.XMLPathCtx} class.
 */
public class XPathHelper {

    /**
     * The Logger.
     */
    private static final Log LOG = LogFactory.getLog(XPathHelper.class); 

    private static XPathFactory sXpathFac = XPathFactory.newInstance();;

    private XPath m_path= sXpathFac.newXPath();


    private Node m_node;

    public XPathHelper(Node node) {
        this.m_node = node;
    }

    public XPathHelper(InputSource is) throws
            SAXException,
            IOException {
        this(XMLUtils.getDocumentBuilder().parse(is));
    }

    public XPathHelper(InputStream pStream) throws SAXException, IOException {
        this(new InputSource(pStream));
    }

    public String querySimpleXPath(String xPath) {
        try {
            String result = (String) m_path.evaluate(xPath, m_node, XPathConstants.STRING);
            String trimmedResult = result.trim();
            return trimmedResult;
        } catch (XPathExpressionException e) {
            IllegalArgumentException iae = new IllegalArgumentException("XPath expression invalid");
            iae.initCause(e);
            throw iae;
        }

    }

    /**
     * @param xPath
     * @param namespaceNode
     * @return
     * @throws XPathExpressionException
     * 
     * @deprecated namespace prefix support will be redesigned
     */
    public String querySimpleXPath(String xPath, String namespaceNode) {
        return querySimpleXPath(xPath);
        // try {
        // Node tNode = cxpath.selectSingleNode(node, xPath, cxpath.selectSingleNode(node, namespaceNode));
        // if (tNode == null) {
        // return null;
        // } else {
        // return tNode.getNodeValue().trim();
        // }
        // } catch (DOMException exception) {
        // return null;
        // } catch (TransformerException te) {
        // return null;
        // }
    }

    public NodeList queryXPath(String xPath) {
        try {
            return (NodeList) m_path.evaluate(xPath, m_node, XPathConstants.NODESET);
        } catch (XPathExpressionException e) {
            IllegalArgumentException iae = new IllegalArgumentException("XPath expression invalid");
            iae.initCause(e);
            throw iae;
        }
    }

    public Node queryXpathNode(String xPath) {
        try {
            return (Node) m_path.evaluate(xPath, m_node, XPathConstants.NODE);
        } catch (XPathExpressionException e) {
            IllegalArgumentException iae = new IllegalArgumentException("XPath expression invalid");
            iae.initCause(e);
            throw iae;
        }

    }

}